==> SMCSolver_1.1-2006.10.23.tgz: SMCSolver_1.1/view_pi.h <==
/**************************************************************
 * Structured Markov Chains Solver       [  SMCSolver  ]      *
 * Dario Bini, Beatrice Meini, Sergio Steffe'                 *
 * bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    *
 * Dipartimento di Matematica "Leonida Tonelli"               *
 * Largo Pontecorvo 5                                         *
 * 56127 Pisa                                                 *
 * Italy                                                      *
 * Version 1.1 - Oct 2006                                     *
 **************************************************************
 *
 *  view_pi.h - view pi vector  - both callbacks and interfaces
 *
 */

/*prototypes view_mat.h */
void create_view_pi_window(void);
void on_view_pi_menu_quit_activate   (GtkMenuItem  *, gpointer );
void on_view_pi_delete_activate   (GtkWidget  *, gpointer );
void on_view_pi_menu_rescale_activate   (GtkMenuItem  *, gpointer );
void on_view_pi_menu_log_activate   (GtkMenuItem  *, gpointer );

void draw_view_pi_area(GtkWidget *, GdkEventExpose *, gpointer);
void pi_image_compute(struct viewpi_str *);
GtkWidget* create_dialog_nogo1(GtkWidget* );
GtkWidget* create_dialog_nogo2(GtkWidget* );

/* prototipes ponte.f90 */
void read_matpi0_(int *, double *);
void read_matpi_(int *, int *,double *);

/* prototypes rw.c */

/* globals view_mat.c */

/* globals main.c */
int is_debug;

/* globals interface.c */
struct running_problem_str  completed; /* we save data here after successfully allocate the matrices with the data in committed */

/* globals main.c */
GtkWidget *window_main;       /* main window */

==> SMCSolver_1.2-2006.11.29-18.tgz: SMCSolver_1.2/view_pi.h <==
/**************************************************************
 * Structured Markov Chains Solver       [  SMCSolver  ]      *
 * Dario Bini, Beatrice Meini, Sergio Steffe'                 *
 * bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    *
 * Dipartimento di Matematica "Leonida Tonelli"               *
 * Largo Pontecorvo 5                                         *
 * 56127 Pisa                                                 *
 * Italy                                                      *
 * Version 1.2 - Nov 2006                                     *
 **************************************************************
 *
 *  view_pi.h - view pi vector  - both callbacks and interfaces
 *
 */

/*prototypes view_mat.h */
void create_view_pi_window(void);
void on_view_pi_menu_quit_activate   (GtkMenuItem  *, gpointer );
void on_view_pi_destroy_activate   (GtkWidget  *, gpointer );
gboolean on_view_pi_delete_activate   (GtkWidget  *, GdkEvent  * ,gpointer );
gboolean on_view_pi_state_print (GtkWidget  *, GdkEvent  * ,gpointer );
void on_view_pi_menu_rescale_activate   (GtkMenuItem  *, gpointer );
void on_view_pi_menu_log_activate   (GtkMenuItem  *, gpointer );

void draw_view_pi_area(GtkWidget *, GdkEventExpose *, gpointer);
void pi_image_compute(struct viewpi_str *);
GtkWidget* create_dialog_nogo1(GtkWidget* );
GtkWidget* create_dialog_nogo2(GtkWidget* );

/* prototipes ponte.f90 */
void read_matpi0_(int *, double *);
void read_matpi_(int *, int *,double *);

/* prototypes rw.c */

/* globals view_mat.c */

/* globals main.c */
int is_debug;

/* globals interface.c */
struct running_problem_str  completed; /* we save data here after successfully allocate the matrices with the data in committed */

/* globals main.c */
GtkWidget *window_main;       /* main window */
